# A quantum alternative for standard Python random package


## Installation : `pip install true-random`

## Features :
- true_randint
- true_choice
- true_shuffle
- true_password

## Example usage :
```python
from truerandom import true_password

print(true_password(length=10))
```
